pub struct TaskOptions {Show 15 fields
pub header: Option<SmallVec<SmolStr>>,
pub split: Option<i32>,
pub all_proxy: Option<SmolStr>,
pub dir: Option<SmolStr>,
pub out: Option<SmolStr>,
pub gid: Option<SmolStr>,
pub continue: Option<bool>,
pub auto_file_renaming: Option<bool>,
pub check_integrity: Option<bool>,
pub lowest_speed_limit: Option<SmolStr>,
pub max_download_limit: Option<SmolStr>,
pub max_connection_per_server: Option<i32>,
pub max_tries: Option<i32>,
pub timeout: Option<i32>,
pub extra_options: SmallMap<SmolStr, Value>,
}Fields
header: Option<SmallVec<SmolStr>>split: Option<i32>all_proxy: Option<SmolStr>dir: Option<SmolStr>out: Option<SmolStr>gid: Option<SmolStr>continue: Option<bool>auto_file_renaming: Option<bool>check_integrity: Option<bool>lowest_speed_limit: Option<SmolStr>Close connection if download speed is lower than or equal to this value(bytes per sec).
0 means aria2 does not have a lowest speed limit.
You can append K or M (1K = 1024, 1M = 1024K).
This option does not affect BitTorrent downloads.
Default: 0
max_download_limit: Option<SmolStr>Set max download speed per each download in bytes/sec. 0 means unrestricted.
You can append K or M (1K = 1024, 1M = 1024K).
To limit the overall download speed, use –max-overall-download-limit option.
Default: 0
max_connection_per_server: Option<i32>max_tries: Option<i32>timeout: Option<i32>extra_options: SmallMap<SmolStr, Value>Trait Implementations
Sourceimpl Clone for TaskOptions
impl Clone for TaskOptions
Sourcefn clone(&self) -> TaskOptions
fn clone(&self) -> TaskOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for TaskOptions
impl Default for TaskOptions
Sourcefn default() -> TaskOptions
fn default() -> TaskOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TaskOptions
impl<'de> Deserialize<'de> for TaskOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more